@@ -9,5 +9,5 @@ class DistributionImage(CamelModel):
     file: BytesIO
     width: int
     height: int
-    orderIndex: int
+    order_index: int
 
