@@ -1,3 +1,4 @@
+import uuid
 from io import BytesIO
 from typing import List
 
@@ -45,18 +46,19 @@ class DistributionSheet(Sheet):
 
         image_index: int = 0
         for image in worksheet._images:
-            image_index += 1
-
             self.distribution_images.append(
                 DistributionImage(
-                    name=str(image_index),
+                    name=str(uuid.uuid4()),
                     format=image.format,
                     file=image.ref,
                     width=image.width,
                     height=image.height,
+                    orderIndex=image_index
                 )
             )
 
+            image_index += 1
+
         self.process_sheet_data()
 
     def process_sheet_data(self) -> None:
