@@ -40,7 +40,7 @@ sheetnames_relationships = {
 
 class MotorcycleModelWorkbook:
     motorcycle_model: Optional[MotorcycleModel]
-    distribution_sheet_images: Optional[List[DistributionImage]]
+    distribution_images: Optional[List[DistributionImage]]
 
     def __init__(
             self,
